@@ -29,8 +29,19 @@
 extern "C" {
 #endif
 
-/* Must be the first thing called in a program. */
-int opennet_init(void);
+typedef struct {
+	int fd;
+	ssize_t (*recv_func)();
+	ssize_t (*send_func)();
+	char *buf;
+	char *buf_s;
+	unsigned long bufsize;
+	unsigned long bufsize_s;
+	unsigned long bufused;
+	int eof;
+	int socket;
+} NETFILE;
+
 
 /* Open a URL.  Same syntax as POSIX open(), except `mode' is required. */
 int open_net(const char *pathname, int flags, mode_t mode);
@@ -42,10 +53,22 @@ off_t lseek_net(int filedes, off_t offset, int whence);
 ssize_t read_net(int fd, void *buf, size_t count);
 
 /* ANSI fopen() clone. */
-FILE *fopen_net(const char *path, const char *mode);
+NETFILE *fopen_net(const char *path, const char *mode);
+
+/* ANSI fgets() clone */
+char *fgets_net(char *s, int size, NETFILE *stream);
+
+/* ANSI feof() clone */
+int feof_net(NETFILE *stream);
+
+/* ANSI fread() clone */
+size_t fread_net(void *ptr, size_t size, size_t nmemb, NETFILE *stream);
 
 /* ANSI fseek() clone. */
-int fseek_net(FILE *stream, long offset, int whence);
+int fseek_net(NETFILE *stream, long offset, int whence);
+
+/* ANSI fclose() clone */
+int fclose_net(NETFILE *stream);
 
 #ifdef  __cplusplus
 }
